@@ -4,8 +4,8 @@ import astropy.units as u
 import numpy as np
 
 from zodipy._coordinates import get_target_coordinates, change_coordinate_system
-from zodipy._integration import INTEGRATION_CONFIGS
-from zodipy.models import MODELS
+from zodipy.integration_configs import integration_configs
+from zodipy.models import models
 from zodipy.simulation import InstantaneousStrategy, TimeOrderedStrategy
 
 
@@ -31,8 +31,6 @@ class Zodi:
             defining a range of times and dates; the range dictionary has to
             be of the form {``'start'``:'YYYY-MM-DD [HH:MM:SS]',
             ``'stop'``:'YYYY-MM-DD [HH:MM:SS]', ``'step'``:'n[y|d|h|m|s]'}.
-            Epoch timescales depend on the type of query performed: UTC for
-            ephemerides queries, TDB for element queries, CT for vector queries.
             If no epochs are provided, the current time is used.
         hit_maps
             The number of times each pixel is observed for a given observation.
@@ -46,51 +44,38 @@ class Zodi:
             'high'. Defaults to 'default'.
         """
 
-        try:
-            model = MODELS[model.lower()]
-        except KeyError:
-            raise KeyError(
-                f"Model {model!r} not found. Available models are: "
-                f"{list(MODELS.keys())}"
-        )
-        try:
-            integration_config = INTEGRATION_CONFIGS[integration_config.lower()]
-        except KeyError:
-            raise KeyError(
-                f"Config {integration_config!r} not found. Available configs "
-                f"are: {list(INTEGRATION_CONFIGS.keys())}"
-        )
-        
+        model = models.get_model(model)
+        integration_config = integration_configs.get_config(integration_config)
+
         observer_locations = get_target_coordinates(observer, epochs) 
         earth_locations = get_target_coordinates('earth', epochs) 
         
-        # We check that the dimensons of hit_map corresponds to the number
-        # of observations.
+        number_of_observations = len(observer_locations)
+        if number_of_observations == 1:
+            observer_locations = observer_locations[0]
+            earth_locations = earth_locations[0]
+
         if hit_maps is not None:
-            if np.ndim(hit_maps) == 1:
-                hit_maps = np.expand_dims(hit_maps, axis=0)
-            elif len(hit_maps) != len(observer_locations):
+            hit_maps = np.asarray(hit_maps)
+            number_of_hitmaps = 1 if np.ndim(hit_maps) == 1 else len(hit_maps)
+            if number_of_hitmaps != number_of_observations:
                 raise ValueError(
-                    f"Lenght of 'hit_maps' ({len(hit_maps)}) are not matching "
-                    f"the number of observations ({len(observer_locations)})"
+                    f"The number of 'hit_maps' ({number_of_hitmaps}) are not "
+                    "matching the number of observations "
+                    f"({number_of_observations})"
                 )
 
-        if len(observer_locations) == 1:
-            self._simulation_strategy = InstantaneousStrategy(
-                model, 
-                integration_config, 
-                observer_locations[0], 
-                earth_locations[0], 
-                hit_maps
-            )
+        if number_of_observations == 1:
+            simulation_strategy = InstantaneousStrategy
         else:
-            self._simulation_strategy = TimeOrderedStrategy(
-                model, 
-                integration_config, 
-                observer_locations, 
-                earth_locations, 
-                hit_maps
-            )     
+            simulation_strategy = TimeOrderedStrategy
+        self._simulation_strategy = simulation_strategy(
+            model, 
+            integration_config, 
+            observer_locations, 
+            earth_locations, 
+            hit_maps
+        )     
 
     def get_emission(
         self, 
